@@ -56,7 +56,6 @@
 #include <Qt3DLogic/qframeaction.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -71,6 +70,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -90,11 +94,12 @@ extern SbkConverter **SbkPySide6_Qt3DLogicTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DLOGIC_QLIST_QT3DCORE_QENTITYPTR_IDX              = 0, // QList<Qt3DCore::QEntity* >
-    SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                         = 1, // QList<QVariant >
-    SBK_QT3DLOGIC_QLIST_QSTRING_IDX                          = 2, // QList<QString >
-    SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                  = 3, // QMap<QString,QVariant >
-    SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                       = 4
+    SBK_QT3DLOGIC_QLIST_INT_IDX                              = 0, // QList<int >
+    SBK_QT3DLOGIC_QLIST_QT3DCORE_QENTITYPTR_IDX              = 1, // QList<Qt3DCore::QEntity* >
+    SBK_QT3DLOGIC_QLIST_QVARIANT_IDX                         = 2, // QList<QVariant >
+    SBK_QT3DLOGIC_QLIST_QSTRING_IDX                          = 3, // QList<QString >
+    SBK_QT3DLOGIC_QMAP_QSTRING_QVARIANT_IDX                  = 4, // QMap<QString,QVariant >
+    SBK_Qt3DLogic_CONVERTERS_IDX_COUNT                       = 5
 };
 // Macros for type check
 
