@@ -89,7 +89,6 @@
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
 #include <qbardataproxy.h>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -105,6 +104,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -177,29 +181,30 @@ extern SbkConverter **SbkPySide6_QtDataVisualizationTypeConverters;
 enum : int {
     SBK_QBARDATAARRAY_IDX                                    = 0,
     SBK_QSURFACEDATAARRAY_IDX                                = 1,
-    SBK_QTDATAVISUALIZATION_QLIST_QCUSTOM3DITEMPTR_IDX       = 2, // QList<QCustom3DItem* >
-    SBK_QTDATAVISUALIZATION_QLIST_QABSTRACT3DINPUTHANDLERPTR_IDX = 3, // QList<QAbstract3DInputHandler* >
-    SBK_QTDATAVISUALIZATION_QLIST_Q3DTHEMEPTR_IDX            = 4, // QList<Q3DTheme* >
-    SBK_QTDATAVISUALIZATION_QLIST_QVALUE3DAXISPTR_IDX        = 5, // QList<QValue3DAxis* >
-    SBK_QTDATAVISUALIZATION_QLIST_QSURFACE3DSERIESPTR_IDX    = 6, // QList<QSurface3DSeries* >
-    SBK_QTDATAVISUALIZATION_QLIST_QSCATTER3DSERIESPTR_IDX    = 7, // QList<QScatter3DSeries* >
-    SBK_QTDATAVISUALIZATION_QLIST_QABSTRACT3DAXISPTR_IDX     = 8, // QList<QAbstract3DAxis* >
-    SBK_QTDATAVISUALIZATION_QLIST_QBAR3DSERIESPTR_IDX        = 9, // QList<QBar3DSeries* >
-    SBK_QTDATAVISUALIZATION_QLIST_QOBJECTPTR_IDX             = 10, // QList<QObject* >
-    SBK_QTDATAVISUALIZATION_QLIST_QBYTEARRAY_IDX             = 11, // QList<QByteArray >
-    SBK_QTDATAVISUALIZATION_QLIST_FLOAT_IDX                  = 12, // QList<float >
-    SBK_QTDATAVISUALIZATION_QLIST_UCHAR_IDX                  = 13, // QList<uchar >
-    SBK_QTDATAVISUALIZATION_QLIST_UNSIGNEDINT_IDX            = 14, // QList<unsigned int >
-    SBK_QTDATAVISUALIZATION_QLIST_QIMAGEPTR_IDX              = 15, // QList<QImage* >
-    SBK_QTDATAVISUALIZATION_QLIST_QSURFACEDATAITEM_IDX       = 16, // QList<QSurfaceDataItem >
-    SBK_QTDATAVISUALIZATION_QLIST_QSCATTERDATAITEM_IDX       = 17, // QList<QScatterDataItem >
-    SBK_QTDATAVISUALIZATION_QLIST_QBARDATAITEM_IDX           = 18, // QList<QBarDataItem >
-    SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                 = 19, // QList<QColor >
-    SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX        = 20, // QList<QLinearGradient >
-    SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX               = 21, // QList<QVariant >
-    SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                = 22, // QList<QString >
-    SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX        = 23, // QMap<QString,QVariant >
-    SBK_QtDataVisualization_CONVERTERS_IDX_COUNT             = 24
+    SBK_QTDATAVISUALIZATION_QLIST_INT_IDX                    = 2, // QList<int >
+    SBK_QTDATAVISUALIZATION_QLIST_QCUSTOM3DITEMPTR_IDX       = 3, // QList<QCustom3DItem* >
+    SBK_QTDATAVISUALIZATION_QLIST_QABSTRACT3DINPUTHANDLERPTR_IDX = 4, // QList<QAbstract3DInputHandler* >
+    SBK_QTDATAVISUALIZATION_QLIST_Q3DTHEMEPTR_IDX            = 5, // QList<Q3DTheme* >
+    SBK_QTDATAVISUALIZATION_QLIST_QVALUE3DAXISPTR_IDX        = 6, // QList<QValue3DAxis* >
+    SBK_QTDATAVISUALIZATION_QLIST_QSURFACE3DSERIESPTR_IDX    = 7, // QList<QSurface3DSeries* >
+    SBK_QTDATAVISUALIZATION_QLIST_QSCATTER3DSERIESPTR_IDX    = 8, // QList<QScatter3DSeries* >
+    SBK_QTDATAVISUALIZATION_QLIST_QABSTRACT3DAXISPTR_IDX     = 9, // QList<QAbstract3DAxis* >
+    SBK_QTDATAVISUALIZATION_QLIST_QBAR3DSERIESPTR_IDX        = 10, // QList<QBar3DSeries* >
+    SBK_QTDATAVISUALIZATION_QLIST_QOBJECTPTR_IDX             = 11, // QList<QObject* >
+    SBK_QTDATAVISUALIZATION_QLIST_QBYTEARRAY_IDX             = 12, // QList<QByteArray >
+    SBK_QTDATAVISUALIZATION_QLIST_FLOAT_IDX                  = 13, // QList<float >
+    SBK_QTDATAVISUALIZATION_QLIST_UCHAR_IDX                  = 14, // QList<uchar >
+    SBK_QTDATAVISUALIZATION_QLIST_UNSIGNEDINT_IDX            = 15, // QList<unsigned int >
+    SBK_QTDATAVISUALIZATION_QLIST_QIMAGEPTR_IDX              = 16, // QList<QImage* >
+    SBK_QTDATAVISUALIZATION_QLIST_QSURFACEDATAITEM_IDX       = 17, // QList<QSurfaceDataItem >
+    SBK_QTDATAVISUALIZATION_QLIST_QSCATTERDATAITEM_IDX       = 18, // QList<QScatterDataItem >
+    SBK_QTDATAVISUALIZATION_QLIST_QBARDATAITEM_IDX           = 19, // QList<QBarDataItem >
+    SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                 = 20, // QList<QColor >
+    SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX        = 21, // QList<QLinearGradient >
+    SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX               = 22, // QList<QVariant >
+    SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                = 23, // QList<QString >
+    SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX        = 24, // QMap<QString,QVariant >
+    SBK_QtDataVisualization_CONVERTERS_IDX_COUNT             = 25
 };
 // Macros for type check
 
