@@ -58,7 +58,6 @@
 #include <QtWebSockets/qwebsocketprotocol.h>
 // Conversion Includes - Primitive Types
 #include <QAnyStringView>
-#include <qabstractitemmodel.h>
 #include <QString>
 #include <QStringList>
 #include <QStringView>
@@ -73,6 +72,11 @@
 #include <QQueue>
 #include <QSet>
 #include <QStack>
+#include <list>
+#include <map>
+#include <utility>
+#include <unordered_map>
+#include <vector>
 
 // Type indices
 enum : int {
@@ -97,14 +101,15 @@ extern SbkConverter **SbkPySide6_QtWebSocketsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTWEBSOCKETS_QLIST_QOBJECTPTR_IDX                    = 0, // QList<QObject* >
-    SBK_QTWEBSOCKETS_QLIST_QBYTEARRAY_IDX                    = 1, // QList<QByteArray >
-    SBK_QTWEBSOCKETS_QLIST_QSSLERROR_IDX                     = 2, // QList<QSslError >
-    SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX    = 3, // QList<QWebSocketProtocol::Version >
-    SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                      = 4, // QList<QVariant >
-    SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                       = 5, // QList<QString >
-    SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX               = 6, // QMap<QString,QVariant >
-    SBK_QtWebSockets_CONVERTERS_IDX_COUNT                    = 7
+    SBK_QTWEBSOCKETS_QLIST_INT_IDX                           = 0, // QList<int >
+    SBK_QTWEBSOCKETS_QLIST_QOBJECTPTR_IDX                    = 1, // QList<QObject* >
+    SBK_QTWEBSOCKETS_QLIST_QBYTEARRAY_IDX                    = 2, // QList<QByteArray >
+    SBK_QTWEBSOCKETS_QLIST_QSSLERROR_IDX                     = 3, // QList<QSslError >
+    SBK_QTWEBSOCKETS_QLIST_QWEBSOCKETPROTOCOL_VERSION_IDX    = 4, // QList<QWebSocketProtocol::Version >
+    SBK_QTWEBSOCKETS_QLIST_QVARIANT_IDX                      = 5, // QList<QVariant >
+    SBK_QTWEBSOCKETS_QLIST_QSTRING_IDX                       = 6, // QList<QString >
+    SBK_QTWEBSOCKETS_QMAP_QSTRING_QVARIANT_IDX               = 7, // QMap<QString,QVariant >
+    SBK_QtWebSockets_CONVERTERS_IDX_COUNT                    = 8
 };
 // Macros for type check
 
